@@ -3,5 +3,5 @@ use clap::Parser;
 #[derive(Parser, Debug)]
 #[clap(author, version, about)]
 pub struct Args {
-    pub path: String,
+    pub path: Option<String>,
 }
